<p align="center"><a href="#"><img width=100% alt="" src="https://github.com/joseph-x-li/pystreaming/blob/main/resources/logo.png?raw=true"></a></p>

# pystreaming

![build](https://github.com/joseph-x-li/pystreaming/workflows/build/badge.svg) 
[![codecov](https://codecov.io/gh/joseph-x-li/pystreaming/branch/main/graph/badge.svg?token=14DXVFUY7Z)](https://codecov.io/gh/joseph-x-li/pystreaming) 
[![Documentation Status](https://readthedocs.org/projects/pystreaming/badge/?version=latest)](https://pystreaming.readthedocs.io/en/latest/?badge=latest) 
[![PyPI version](https://badge.fury.io/py/pystreaming.svg)](https://badge.fury.io/py/pystreaming) 
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

[Documentation](https://pystreaming.readthedocs.io/)

Easy streaming of video and audio using fast jpg compression. 

Designed for ease of installation: no ffmpeg, no gstreamer.
